"""
	Module containing the GitHub issue crawler
	HEADERS const must have a valid token
"""

import sys
import os
import json
from pathlib import Path
import requests
import pandas as pd

sys.path.append(
    str(Path(os.path.abspath('')).absolute().parent.parent.parent.parent))

from deeperMatcher.src.issues.issue_collector import IssueCollector
from deeperMatcher.src.issues.issue_repository import IssueRepository

ISSUES_PER_PAGE = 100
REQUEST_TIMEOUT = 120  #in seconds
GITHUB_TOKEN = ""  # insert your token here!

HEADERS = {
    'Accept': 'application/vnd.github.v3+json',
    'Authorization': 'token ' + GITHUB_TOKEN,
}


class GitHubCrawler(IssueCollector):  # pylint: disable=too-few-public-methods
	"""
		Scraper issues from a GitHub repository
	"""

	def __init__(self, project_origin: str, persistency_path: str,
	             repository_url: str):
		self.project_origin = project_origin
		self.persistency_path = persistency_path
		self.repository_url = repository_url
		super().__init__()

	def collect_issues(self) -> IssueRepository:
		"""
			Returns an IssueRepository with the issues scraped
		"""

		all_issues = []
		page = 0

		while True:
			issues = get_issues(self.repository_url, page)

			print(f'added page {page}')
			all_issues += issues
			page += 1
			print(len(issues))
			if len(issues) <= 2:
				break

		df = pd.DataFrame(all_issues)
		df = df[df['pull_request'].isna()]

		new_repo = IssueRepository(self.project_origin, self.persistency_path)
		new_repo.load_from_df(df)

		return new_repo


def get_issues(url, page):
	"""
		Scrapes issues from one of a repositorie's 
		issue pages.
	"""
	params = {
	    'per_page': ISSUES_PER_PAGE,
	    'page': page,
	    'state': 'all',
	    'labels': 'bug'
	}

	response = requests.get(url,
	                        headers=HEADERS,
	                        params=params,
	                        timeout=REQUEST_TIMEOUT)
	issues = json.loads(response.text)
	return issues
