"""
Code for DeeperMatcher's main script
"""

import sys
import os
from pathlib import Path

import argparse

sys.path.append(str(Path(os.path.abspath('')).absolute()))

from deeperMatcher.src.execution_modes.match_review import match_review_to_issues

DEFAULT_ISSUES_PER_REVIEW = 3
DEFAULT_SIMILARITY_THRESHOLD = 0.8


def parse_args():
	'''
   	    Parses command line arguments
   	'''
	arg_parser = argparse.ArgumentParser()

	arg_parser.add_argument("-m",
	                        "--mode",
	                        action='store',
	                        choices=['r', 'i'],
	                        default='r',
	                        help="""Execution mode. Choose between:\
	'r': To look for matches to one or more user reviews; or
	'i': To look for matches to a given issue;""")
	arg_parser.add_argument("-i",
	                        "--issues",
	                        action='store',
	                        required=True,
	                        help='Issue Repository file (inside data dir)')
	arg_parser.add_argument("-r",
	                        "--reviews",
	                        action='store',
	                        required=False,
	                        help='User Feedback Repo file (inside data dir)')
	arg_parser.add_argument("-out",
	                        "--output_path",
	                        action='store',
	                        required=False,
	                        help='Path to store program output')
	arg_parser.add_argument("-n",
	                        "--issuesPerReview",
	                        action='store',
	                        default=DEFAULT_ISSUES_PER_REVIEW,
	                        help='Issues matched to each user review')
	arg_parser.add_argument("-similarity",
	                        "--similarityThreshold",
	                        action='store',
	                        default=DEFAULT_SIMILARITY_THRESHOLD,
	                        help='Minimum similarity for listed matches')
	arg_parser.add_argument(
	    "-c",
	    "--classify",
	    action='store_true',
	    required=False,
	    help='Classify user reviews and only select problem reports')
	arg_parser.add_argument("-lang",
	                        "--language",
	                        action='store',
	                        required=False,
	                        help='Language used by the issues and user reviews')

	args = arg_parser.parse_args()

	return args


def main():
	'''
   	Main function
   	'''
	args = parse_args()

	if args.mode == "r":
		match_review_to_issues(args)
	elif args.mode == "i":
		print("matching reviews to issue")
	else:
		print("Invalid execution mode.")
		sys.exit(1)


if __name__ == "__main__":
	main()
