"""
	Module containing code for creating embeddings
"""

import logging
import sys
import os
from pathlib import Path
from tqdm import tqdm

sys.path.append(str(Path(os.path.abspath('')).absolute().parent.parent.parent))

from deeperMatcher.src.utils import data_loader
from deeperMatcher.src.issues.issue_repository import IssueRepository
from deeperMatcher.src.text_embedding.text_embedder import TextEmbedder

logging.basicConfig(level=logging.WARNING)
logger = logging.getLogger(__name__)
logger.setLevel(level=logging.INFO)


def embed_issues(embeddings_file: str, issue_rep: IssueRepository, limit: int):
	"""
		Embeds every issue from a given repository
	"""
	embeddings = data_loader.load_embeddings(embeddings_file)
	embedder = TextEmbedder()

	issues = issue_rep.get_issues()
	if limit:
		issues = issues[:limit]

	new_embeddings = 0
	for issue in tqdm(issues):
		issue_id, issue_text = (issue.get_id(), issue.get_summary())
		if issue_id not in embeddings:
			issue_embedding = embedder.embed_text(issue_text)
			embeddings[issue_id] = issue_embedding
			new_embeddings += 1

	if new_embeddings > 0:
		data_loader.save_embeddings(embeddings_file, embeddings)
	else:
		logger.info('no new embedding for %s', embeddings_file)
