"""
	Module containing the definition of the AppReviewClassifier class
"""

import sys
import os
from pathlib import Path
from typing import Callable
from tqdm import tqdm

sys.path.append(str(Path(os.path.abspath('')).absolute()))

from deeperMatcher.src.user_feedback.classifier.hf_model_based_classifier.hf_model_based_classifier import HF_Model_Based_Classifier  #pylint: disable=line-too-long
from deeperMatcher.src.user_feedback.user_feedback import UserFeedback
from deeperMatcher.src.user_feedback.user_feedback_repository import UserFeedbackRespository


class AppReviewClassifier():
	"""
	Class for a generic user feedback classifier. Useful as to 
	abstract which classifier implementation is currently being used.
	"""

	def __init__(self, translating_func: Callable | None = None) -> None:
		self.classifier = HF_Model_Based_Classifier()
		if translating_func is None:
			self.translate = lambda x: x
		else:
			self.translate = translating_func

	def classify_review(self, text) -> str:
		"""
		Classifies a given user review
		"""
		translated_text = self.translate(text)
		return self.classifier.classify_review(translated_text)

	def get_problem_reports_from_repo(
	        self, feedback_repo: UserFeedbackRespository) -> list[UserFeedback]:
		"""
		Classifies user reviews from a UserFeedbackRepository and returns 
		a list containing those classified as 'bug_report'
		"""

		reviews = feedback_repo.get_feedback_entries()
		reports = []

		print("Classifying user reviews")
		for review in tqdm(reviews):
			translated_text = self.translate(review.get_content())
			result = self.classify_review(translated_text)
			if result == "bug_report":
				reports.append(review)

		return reports
