"""
	Module responsible for containing the Hugging Face Model
Based Classifier class.
"""

import sys
import os
from pathlib import Path
from transformers import AutoTokenizer, pipeline

sys.path.append(str(Path(os.path.abspath('')).absolute()))

from deeperMatcher.src.utils.constants import MODELS_DIR

MODEL_NAME = "simple_feedback_classifier"
PATH_TO_MODEL = MODELS_DIR + MODEL_NAME


class HF_Model_Based_Classifier():
	"""
	English written Feedback classifier based on a Hugging Faced trained
	model.
	"""

	def __init__(self) -> None:
		tokenizer = AutoTokenizer.from_pretrained(
		    "distilbert/distilbert-base-uncased", model_max_length=512)

		self.hf_pipeline = pipeline("text-classification",
		                            model=PATH_TO_MODEL,
		                            tokenizer=tokenizer)

	def classify_review(self, text):
		"""
		Classifies a given user review written in english.
		"""

		tokenizer_kwargs = {'truncation': True, 'max_length': 512}

		result = self.hf_pipeline(text, **tokenizer_kwargs)
		label = result[0]["label"]

		if label == "pbr":
			return 'bug_report'
		if label == "inq":
			return 'feature_request'
		return 'irrelevant'
