"""
 Module containing the MLFacade class
 Author: Christoph Stanik
 Date: 9th June 2017

 Updated by Arthur Pilone at Feb 14th 2024
"""

POSSIBLE_FEATURES = [
    "feature_contains_keywords_bug",
    "feature_contains_keywords_feature_request", "feature_tense_past",
    "feature_tense_present", "feature_tense_future", "feature_rating",
    "feature_sentiment_score_pos", "feature_sentiment_score_neg",
    "feature_sentiment_score_single", "feature_word_count", "feature_bow",
    "feature_bigram", "feature_keyword_bug", "feature_keyword_freeze",
    "feature_keyword_crash", "feature_keyword_glitch", "feature_keyword_wish",
    "feature_keyword_should", "feature_keyword_add"
]


class MLFacade:  #pylint: disable=too-few-public-methods
	"""
	 	This class is responsible for:
		1.0 create a data sample for testing machine learning classifiers
		2.0 perform machine learning by creating a training model
		3.0 perform cross validation
		4.0 compares the results of all classifiers and machine learning features
		5.0 prints the result of the best performing classifier and machine learning features

		Rationale:
		- we want to compare different classifiers
		- we want to compare different combinations of machine learning features
		- we don't want to see the results of all possible combinations and concentrate on the best
	"""

	@staticmethod
	def get_ml_features(app_review=None, ml_features=None):
		"""
			Returns a subset of an app review's features
		"""

		if "all" in ml_features:
			return POSSIBLE_FEATURES.copy()

		features_single_app_review = []
		for possible_feature in POSSIBLE_FEATURES:
			if possible_feature in ml_features:
				features_single_app_review.append(app_review[possible_feature])

		return features_single_app_review
