"""
	Module containing the google play app review crawler
"""

import sys
import os
from pathlib import Path

from deeperMatcher.src.user_feedback.user_feedback_repository import UserFeedbackRespository

sys.path.append(str(Path(os.path.abspath('')).absolute()))

from google_play_scraper import Sort, reviews
from deeperMatcher.src.user_feedback.user_feedback_collector import UserFeedbackCollector


class GooglePlayFeedbackCollector(UserFeedbackCollector):  # pylint: disable=too-few-public-methods
	"""
		Class capable of collecting the feedback from a single application
	from the google play store.
	"""

	def __init__(self, app_name: str, persistency_path: str, app_id: str):
		self.app = app_name
		self.app_id = app_id

		self.persistency_path = persistency_path

	def collect_user_feedback(self, count=10_000) -> UserFeedbackRespository:
		"""
			Returns {count} reviews from the google play store
		reviews 
		"""

		app_reviews, _ = reviews(
		    self.app_id,
		    lang='en',  # defaults to 'en'
		    country='us',  # defaults to 'us'
		    sort=Sort.MOST_RELEVANT,  # defaults to Sort.MOST_RELEVANT
		    count=count,  # defaults to 100
		    filter_score_with=None)

		for review in app_reviews:
			review['app'] = self.app

		return app_reviews


# firefox_reviews_collector = GooglePlayFeedbackCollector(Const.FIREFOX,Const.FIREFOX_REVIEWS,Const.FIREFOX_ID)
# firefox_reviews = firefox_reviews_collector.collect_user_feedback()
# firefox_reviews.save()

# firefox_reviews = get_reviews(Const.FIREFOX_ID)
# vlc_reviews = get_reviews(Const.VLC_ID)
# signal_reviews = get_reviews(Const.SIGNAL_ID)
# nextcloud_reviews = get_reviews(Const.NEXTCLOUD_ID)

# app_reviews = firefox_reviews + vlc_reviews + signal_reviews

# df = pd.DataFrame(nextcloud_reviews)
# data_loader.save_df_compressed(Const.NEXTCLOUD_REVIEWS, df)
# print(df)
