"""
	Module responsible for containing various data parsers
"""

import sys
import os
from pathlib import Path
from datetime import datetime
import numpy as np

sys.path.append(str(Path(os.path.abspath('')).absolute()))

from deeperMatcher.src.utils.user_choice import Choice

GITLAB_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
PYTHON_MS_DATE_FORMAT = "%Y-%m-%d %H:%M:%S.%f"


def is_it_nan(val):
	"""
	Parses a given value and decides whether it is a NaN value
	"""

	try:
		return np.isnan(val)
	except TypeError:
		return False


def parse_datetime_str(date_str: str):
	"""
	Parses a string to a corresponding datetime object
	"""
	try:
		new_date = datetime.strptime(date_str, "%Y-%m-%dT%H:%M:%SZ")
	except ValueError:
		try:
			new_date = datetime.strptime(date_str, GITLAB_DATE_FORMAT)
		except ValueError:
			try:
				new_date = datetime.strptime(date_str, PYTHON_MS_DATE_FORMAT)
			except ValueError:
				new_date = datetime.strptime(date_str, "%Y-%m-%d %H:%M:%S")

	return new_date


def parse_user_choice(input_string: str) -> Choice:
	"""
	Parses a given string containing the user's input into 
	the choice it conveys.
	"""

	low_case_str = input_string.lower()

	if low_case_str in ("y", "yes", "s"):
		return Choice.YES
	if low_case_str in ("n", "no"):
		return Choice.NO
	if low_case_str in ("q", "quit", "exit"):
		return Choice.QUIT
	return Choice.IRR
