"""
Module containing the basic TextTranslator class
"""
import time
from googletrans import Translator, constants


class TextTranslator():  #pylint: disable=too-few-public-methods
	"""
	Generic class responsible for text translation	
	"""

	def __init__(self) -> None:
		self.translator = Translator()

	def translate_to_english(self,
	                         input_text: str,
	                         source_lang: str = "auto") -> str:
		"""
		Translates a given text to english
		"""

		if source_lang not in constants.LANGUAGES and source_lang != "auto":
			raise ValueError("Invalid source language code")

		wait_time = 1
		timed_out = True

		while timed_out:
			try:
				translation_result = self.translator.translate(input_text,
				                                               src=source_lang)
				timed_out = False
			except AttributeError:
				time.sleep(wait_time)
				wait_time += 5

		return translation_result.text
