import sys
import os
from pathlib import Path
import random
import pandas as pd

sys.path.append(str(Path(os.path.abspath(__file__)).absolute().parent.parent.parent.parent))

import deeperMatcher.src.utils.constants as Const
import deeperMatcher.src.utils.data_loader as data_loader
from deeperMatcher.src.analysis.sampled_ids import sampled_ids
from deeperMatcher.src.matching.codings_creator import create_codings_in_repo
from deeperMatcher.src.user_feedback.random_sampling import select_random_reviews
from deeperMatcher.src.issues.issue_repository import IssueRepository
from deeperMatcher.src.text_embedding.text_embedder import TextEmbedder

def test_reproduces_codings():
	SEED = 42
	NUM_SAMPLES = 100

	random.seed(SEED)

	app_reviews = data_loader.load_df_compressed(Const.APP_REVIEWS)
	signal_issues = IssueRepository._from_compressed_df("Test Signal Issues",Const.SIGNAL_ISSUES)

	haering_embedder = TextEmbedder()

	for issue in signal_issues.get_issues():
		if not issue.has_embedding():
			issue.embed_with(haering_embedder)
			
	random_signal_reviews = select_random_reviews(app_reviews, Const.SIGNAL_ID, NUM_SAMPLES,sampled_ids,SEED)
	new_codings = create_codings_in_repo(random_signal_reviews, signal_issues, haering_embedder, 'app', 'app_review')
	new_codings_df = pd.DataFrame(new_codings)

	csv_path = str(Path(os.path.abspath(__file__)).absolute().parent.parent) + "/testing_data/original_matches.csv"
	original_codings_df = pd.read_csv(csv_path)

	for i in range(len(new_codings_df)//3):
		new_slice = new_codings_df.iloc[3*i:3*(i+1)]["issue_id"].values.sort()
		old_slice = original_codings_df.iloc[3*i:3*(i+1)]["issue_id"].values.sort()

		assert(new_slice == old_slice)

	signal_issues.save()