import sys
import os
from pathlib import Path

sys.path.append(str(Path(os.path.abspath(__file__)).absolute().parent.parent.parent.parent))

from deeperMatcher.src.utils.parsers import parse_datetime_str
from deeperMatcher.src.issues.issue import Issue
from deeperMatcher.src.issues.issue_repository import IssueRepository

from deeperMatcher.tests.mocks import mock_issues as mock

def test_issue_from_dict():

	mock_issue = mock.mock_issue_dict

	issue = Issue.from_dict(mock_issue)

	assert isinstance(issue,Issue)
	assert issue.identifier == "67"
	assert issue.summary == mock_issue["title"]
	assert issue.creation_time == parse_datetime_str(mock_issue["created_at"])
	assert issue.completion_time == None
	assert issue.extra_data == {"random_key": 43, "other_field": "strange value"}

def test_issue_repository_accepts_issues():

	repo = IssueRepository("","My App")

	repo.add_issue(mock.mock_issue)
	repo.add_issue(mock.mock_issue_2)

	assert mock.mock_issue in repo.get_issues()
	assert mock.mock_issue_2 in repo.get_issues()
	assert len(repo.get_issues()) == 2

def test_issue_repository_retrieves_issue():

	repo = IssueRepository("","My App")

	assert repo.get_issue("67") == None

	repo.add_issue(mock.mock_issue)

	assert mock.mock_issue == repo.get_issue("67")

def test_issue_repository_gets_issues_subset():
	repo = IssueRepository("","My App")

	repo.add_issue(mock.mock_issue)
	repo.add_issue(mock.mock_issue_2)
	repo.add_issue(mock.mock_issue_3)

	query_result = repo.get_issues_in(["67","70"])

	assert mock.mock_issue in query_result
	assert mock.mock_issue_3 in query_result
	assert len(query_result) == 2