import sys
import os
from pathlib import Path

sys.path.append(str(Path(os.path.abspath(__file__)).absolute().parent.parent.parent.parent))

from deeperMatcher.src.utils.parsers import parse_datetime_str
from deeperMatcher.src.user_feedback.user_feedback import UserFeedback
from deeperMatcher.src.user_feedback.user_feedback_repository import UserFeedbackRespository

from deeperMatcher.tests.mocks import mock_reviews as mock

def test_feedback_from_dict():

	user_review = UserFeedback.from_dict(mock.mock_review_dict,default_app="example_id")

	assert isinstance(user_review,UserFeedback)
	assert user_review.get_id() == "67"
	assert user_review.get_content() == mock.mock_review_dict["content"]
	assert user_review.get_app_id() == "example_id"
	assert user_review.creation_time == parse_datetime_str(mock.mock_review_dict["created_at"])
	assert user_review.extra_data == '{"score": 43, "other_field": "strange value"}'


def test_feedback_repository_accepts_issues():

	repo = UserFeedbackRespository("My App","")

	repo.add_feedback(mock.mock_review)
	repo.add_feedback(mock.mock_review_2)

	assert mock.mock_review in repo.get_feedback_entries()
	assert mock.mock_review_2 in repo.get_feedback_entries()
	assert len(repo.get_feedback_entries()) == 2

def test_feedback_repository_retrieves_feedback():

	repo = UserFeedbackRespository("My App","")

	assert repo.get_feedback_from_id("67") == None

	repo.add_feedback(mock.mock_review)

	assert mock.mock_review == repo.get_feedback_from_id("67")
