"""
	Module containing helper methods for loading issues, reports and embeddings
"""

import logging
import pickle

import pandas as pd

logger = logging.getLogger(__file__)
logger.setLevel(level=logging.INFO)


def load_df_compressed(file):
	"""
		Loads a (gzip) compressed panda df from the given path 
	"""
	return pd.read_csv(file, compression='gzip', lineterminator='\n')


def save_df_compressed(file, df):
	"""
		Saves a (gzip) compressed panda df to the given path 
	"""
	return df.to_csv(file, compression='gzip', index=False)


def load_embeddings(file):
	"""
		Loads a pickle file containing embeddings from a given path
	"""
	try:
		with open(file, 'rb') as f:
			embeddings = pickle.load(f)
			logger.info('embeddings loaded from: %s', file)
			return embeddings
	except FileNotFoundError:
		logger.info('embeddings file not found at: %s', file)
		return {}


def save_embeddings(file, embeddings):
	"""
		Saves a pickle file containing embeddings at a given path
	"""
	with open(file, 'wb') as f:
		pickle.dump(embeddings, f, pickle.HIGHEST_PROTOCOL)
		logger.info('stored embeddings to %s', file)
